@@ -6,7 +6,11 @@ ANY_FAIL=0
 for I in *.in
 do
 	B=$(basename "$I" .in)
-	cat "$B.in" | $1 apertium-eng-spa.spa-eng.arx > "$B.tmp"
+	ARX=apertium-eng-spa.spa-eng.arx
+	if [[ $B == "empty" ]] ; then
+		ARX=empty.arx
+	fi
+	cat "$B.in" | $1 $ARX > "$B.tmp"
 	diff -wb "$B.tmp" "$B.out" > "$B.diff"
 	if [[ $? -eq 0 ]] ; then
 		echo "SUCCESS $B"
